..
.. Copyright (c) 2017, 2020 ADLINK Technology Inc.
..
.. This program and the accompanying materials are made available under the
.. terms of the Eclipse Public License 2.0 which is available at
.. http://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
.. which is available at https://www.apache.org/licenses/LICENSE-2.0.
..
.. SPDX-License-Identifier: EPL-2.0 OR Apache-2.0
..
.. Contributors:
..   ADLINK zenoh team, <zenoh@adlink-labs.tech>
..


Zenoh API Reference
===================

.. automodule:: zenoh
    :members: init_logger


Zenoh
-----
.. autoclass:: zenoh.Zenoh
    :members:

Workspace
---------
.. autoclass:: zenoh.Workspace
    :members:

Subscriber
----------
.. autoclass:: zenoh.Subscriber
    :members:

Eval
----
.. autoclass:: zenoh.Eval
    :members:

Value
-----
.. autoclass:: zenoh.Value
    :members:

Data
----
.. autoclass:: zenoh.Data
    :members:

Selector
--------
.. autoclass:: zenoh.Selector
    :members:

ChangeKind
----------
.. autoclass:: zenoh.ChangeKind
    :members:
    :undoc-members:

Change
------
.. autoclass:: zenoh.Change
    :members:

GetRequest
----------
.. autoclass:: zenoh.GetRequest
    :members:
